@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2014-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2014-2020 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -80,7 +80,9 @@
 #include <QItemSelection>
 #include <QItemSelectionModel>
 #include <QMouseEvent>
+#ifndef QT_NO_OPENGL
 #include <QOpenGLContext>
+#endif
 #include <QSGNode>
 #include <QSGGeometry>
 #include <QSGMaterial>
@@ -95,7 +97,9 @@
 #if QT_VERSION >= QT_VERSION_CHECK(5, 8, 0)
 #include <QSGRenderNode>
 #include <QSGRendererInterface>
+#ifndef QT_NO_OPENGL
 #include <private/qquickopenglshadereffectnode_p.h>
+#endif
 #include <private/qsgsoftwarecontext_p.h>
 #include <private/qsgsoftwarerenderer_p.h>
 #include <private/qsgsoftwarerenderablenode_p.h>
@@ -103,7 +107,9 @@
 
 #include <private/qquickanchors_p.h>
 #include <private/qquickitem_p.h>
+#ifndef QT_NO_OPENGL
 #include <private/qsgbatchrenderer_p.h>
+#endif
 #include <private/qsgdistancefieldglyphnode_p_p.h>
 #include <private/qabstractanimation_p.h>
 
@@ -310,6 +316,11 @@ void RenderModeRequest::apply()
     if (connection)
         disconnect(connection);
 
+#if QT_VERSION == QT_VERSION_CHECK(5, 14, 0) || QT_VERSION == QT_VERSION_CHECK(5, 14, 1)
+    // there's a regression in Qt 5.14...
+    return;
+#endif
+
 #if QT_VERSION >= QT_VERSION_CHECK(5, 8, 0)
     if (window && window->rendererInterface()->graphicsApi() != QSGRendererInterface::OpenGL)
         return;
@@ -398,8 +409,10 @@ QuickInspector::QuickInspector(Probe *probe, QObject *parent)
     connect(m_pendingRenderMode, &RenderModeRequest::aboutToCleanSceneGraph, this, &QuickInspector::aboutToCleanSceneGraph);
     connect(m_pendingRenderMode, &RenderModeRequest::sceneGraphCleanedUp, this, &QuickInspector::sceneGraphCleanedUp);
 
+#ifndef QT_NO_OPENGL
     auto texGrab = new QSGTextureGrabber(this);
     connect(probe, &Probe::objectCreated, texGrab, &QSGTextureGrabber::objectCreated);
+#endif
 
     connect(Endpoint::instance(), &Endpoint::disconnected, this, [this]() {
         if (m_overlay)
@@ -602,6 +615,11 @@ void QuickInspector::slotGrabWindow()
 void QuickInspector::setCustomRenderMode(
     GammaRay::QuickInspectorInterface::RenderMode customRenderMode)
 {
+#if QT_VERSION == QT_VERSION_CHECK(5, 14, 0) || QT_VERSION == QT_VERSION_CHECK(5, 14, 1)
+    // there's a regression in Qt 5.14...
+    return;
+#endif
+
     m_renderMode = customRenderMode;
 
     m_pendingRenderMode->applyOrDelay(m_window, customRenderMode);
@@ -623,9 +641,12 @@ void QuickInspector::checkFeatures()
     }
 
 #if QT_VERSION >= QT_VERSION_CHECK(5, 8, 0)
+#if QT_VERSION != QT_VERSION_CHECK(5, 14, 0) && QT_VERSION != QT_VERSION_CHECK(5, 14, 1)
     if (m_window->rendererInterface()->graphicsApi() == QSGRendererInterface::OpenGL)
         f = AllCustomRenderModes;
-    else if (m_window->rendererInterface()->graphicsApi() == QSGRendererInterface::Software)
+    else
+#endif
+    if (m_window->rendererInterface()->graphicsApi() == QSGRendererInterface::Software)
         f = AnalyzePainting;
 #else
     f = AllCustomRenderModes;
@@ -654,7 +675,7 @@ void QuickInspector::checkOverlaySettings()
 class SGSoftwareRendererPrivacyViolater : public QSGAbstractSoftwareRenderer
 {
 public:
-#if QT_VERSION >= QT_VERSION_CHECK(5, 12, 0)
+#if QT_VERSION >= QT_VERSION_CHECK(5, 12, 0) && QT_VERSION < QT_VERSION_CHECK(5, 14, 0)
     using QSGAbstractSoftwareRenderer::renderableNodes;
 #endif
     using QSGAbstractSoftwareRenderer::renderNodes;
@@ -684,7 +705,7 @@ void QuickInspector::analyzePainting()
         renderer->markDirty();
         renderer->buildRenderList();
         renderer->optimizeRenderList();
-#if QT_VERSION < QT_VERSION_CHECK(5, 12, 0)
+#if QT_VERSION < QT_VERSION_CHECK(5, 12, 0) || QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
         renderer->renderNodes(&painter);
 #else
         auto iterator = renderer->renderableNodes().begin();
@@ -923,10 +944,14 @@ void QuickInspector::registerMetaTypes()
     MO_ADD_METAOBJECT1(QQuickWindow, QWindow);
     MO_ADD_PROPERTY(QQuickWindow, clearBeforeRendering, setClearBeforeRendering);
     MO_ADD_PROPERTY_RO(QQuickWindow, effectiveDevicePixelRatio);
+#ifndef QT_NO_OPENGL
     MO_ADD_PROPERTY(QQuickWindow, isPersistentOpenGLContext, setPersistentOpenGLContext);
+#endif
     MO_ADD_PROPERTY(QQuickWindow, isPersistentSceneGraph, setPersistentSceneGraph);
     MO_ADD_PROPERTY_RO(QQuickWindow, mouseGrabberItem);
+#ifndef QT_NO_OPENGL
     MO_ADD_PROPERTY_RO(QQuickWindow, openglContext);
+#endif
     MO_ADD_PROPERTY_RO(QQuickWindow, renderTargetId);
 #if QT_VERSION >= QT_VERSION_CHECK(5, 8, 0)
     MO_ADD_PROPERTY_RO(QQuickWindow, rendererInterface);
@@ -1041,6 +1066,7 @@ void QuickInspector::registerMetaTypes()
 
     MO_ADD_METAOBJECT1(QSGVertexColorMaterial, QSGMaterial);
 
+#ifndef QT_NO_OPENGL
     MO_ADD_METAOBJECT1(QSGDistanceFieldTextMaterial, QSGMaterial);
     MO_ADD_PROPERTY_RO(QSGDistanceFieldTextMaterial, color);
     MO_ADD_PROPERTY_RO(QSGDistanceFieldTextMaterial, fontScale);
@@ -1059,6 +1085,7 @@ void QuickInspector::registerMetaTypes()
     MO_ADD_PROPERTY_MEM(QQuickOpenGLShaderEffectMaterial, geometryUsesTextureSubRect);
     MO_ADD_PROPERTY_MEM(QQuickOpenGLShaderEffectMaterial, textureProviders);
 #endif
+#endif
 }
 
 #if QT_VERSION >= QT_VERSION_CHECK(5, 8, 0)
@@ -1180,12 +1207,14 @@ void QuickInspector::registerVariantHandlers()
 
 void QuickInspector::registerPCExtensions()
 {
+#ifndef QT_NO_OPENGL
     PropertyController::registerExtension<MaterialExtension>();
     PropertyController::registerExtension<SGGeometryExtension>();
     PropertyController::registerExtension<QuickPaintAnalyzerExtension>();
     PropertyController::registerExtension<TextureExtension>();
 
     PropertyAdaptorFactory::registerFactory(QQuickOpenGLShaderEffectMaterialAdaptorFactory::instance());
+#endif
     PropertyAdaptorFactory::registerFactory(QuickAnchorsPropertyAdaptorFactory::instance());
     PropertyFilters::registerFilter(PropertyFilter("QQuickItem", "anchors"));
 
